searchData={"content_type":"text/markdown","items":[{"doc":"NIF for secp256k1 curve functions.\n\nIt uses https://github.com/paritytech/libsecp256k1","ref":"ExSecp256k1.html","title":"ExSecp256k1","type":"module"},{"doc":"Create a public key from a private key\n\nExamples\n\n    iex> private_key = :crypto.strong_rand_bytes(32)\n    iex> {:ok, _public_key} = ExSecp256k1.create_public_key(private_key)","ref":"ExSecp256k1.html#create_public_key/1","title":"ExSecp256k1.create_public_key/1","type":"function"},{"doc":"Tweak public key by adding to it\n\nExamples\n\n    iex> private_key =  >\n    iex> {:ok, _result} = ExSecp256k1.private_key_tweak_add(private_key, private_key)","ref":"ExSecp256k1.html#private_key_tweak_add/2","title":"ExSecp256k1.private_key_tweak_add/2","type":"function"},{"doc":"Tweak private key by multiplying it\n\nExamples\n\n    iex> private_key =  >\n    iex> {:ok, _result} = ExSecp256k1.private_key_tweak_mult(private_key, private_key)","ref":"ExSecp256k1.html#private_key_tweak_mult/2","title":"ExSecp256k1.private_key_tweak_mult/2","type":"function"},{"doc":"Compresses public key\n\nExamples\n\n    iex> public_key =  >\n    iex> {:ok, _result} = ExSecp256k1.public_key_compress(public_key)","ref":"ExSecp256k1.html#public_key_compress/1","title":"ExSecp256k1.public_key_compress/1","type":"function"},{"doc":"Decompresses public key\n\nExamples\n\n    iex> public_key =  >\n    iex> {:ok, _result} = ExSecp256k1.public_key_decompress(public_key)","ref":"ExSecp256k1.html#public_key_decompress/1","title":"ExSecp256k1.public_key_decompress/1","type":"function"},{"doc":"Tweak public key by adding to it\n\nExamples\n\n    iex> public_key =  >\n    iex> tweak_key =  >\n    iex> {:ok, _result} = ExSecp256k1.public_key_tweak_add(public_key, tweak_key)","ref":"ExSecp256k1.html#public_key_tweak_add/2","title":"ExSecp256k1.public_key_tweak_add/2","type":"function"},{"doc":"Tweak public key by multiplying it\n\nExamples\n\n    iex> public_key =  >\n    iex> tweak_key =  >\n    iex> {:ok, _result} = ExSecp256k1.public_key_tweak_mult(public_key, tweak_key)","ref":"ExSecp256k1.html#public_key_tweak_mult/2","title":"ExSecp256k1.public_key_tweak_mult/2","type":"function"},{"doc":"Recover public key from a message, its signature and a recovery id\n\nExamples\n\n    iex> hash =  >\n    iex> r =  >\n    iex> s =  >\n    iex> recovery_id = 0\n    iex> {:ok, _public_key_binary} = ExSecp256k1.recover(hash, r, s, recovery_id)\n    iex> {:error, :recovery_failure} = ExSecp256k1.recover(hash, r, s, 2)","ref":"ExSecp256k1.html#recover/4","title":"ExSecp256k1.recover/4","type":"function"},{"doc":"Recover public key from a message, its compact signature and a recovery id\n\nExamples\n\n    iex> hash =  >\n    iex> r =  >\n    iex> s =  >\n    iex> recovery_id = 0\n    iex> {:ok, _public_key_binary} = ExSecp256k1.recover_compact(hash, r   s, recovery_id)\n    iex> {:error, :recovery_failure} = ExSecp256k1.recover_compact(hash, r    s, 2)","ref":"ExSecp256k1.html#recover_compact/3","title":"ExSecp256k1.recover_compact/3","type":"function"},{"doc":"Sign a message with the provided private key\n\nExamples\n\n    iex> message =  >\n    iex> private_key =  >\n    iex> {:ok, {_r_binary, _s_binary, _recovery_id_int}} = ExSecp256k1.sign(message, private_key)","ref":"ExSecp256k1.html#sign/2","title":"ExSecp256k1.sign/2","type":"function"},{"doc":"Sign a message with the provided private key. It returns a compact signature\n\nExamples\n\n    iex> message =  >\n    iex> private_key =  >\n    iex> {:ok, {_signature_bin, _recovery_id_int}} = ExSecp256k1.sign_compact(message, private_key)","ref":"ExSecp256k1.html#sign_compact/2","title":"ExSecp256k1.sign_compact/2","type":"function"},{"doc":"Verify a signature of a message\n\nExamples\n\n    iex> message = :crypto.strong_rand_bytes(32)\n    iex> private_key = :crypto.strong_rand_bytes(32)\n    iex> {:ok, {signature, _r}} = ExSecp256k1.sign_compact(message, private_key)\n    iex> {:ok, public_key} = ExSecp256k1.create_public_key(private_key)\n    iex> :ok = ExSecp256k1.verify(message, signature, public_key)","ref":"ExSecp256k1.html#verify/3","title":"ExSecp256k1.verify/3","type":"function"},{"doc":"","ref":"ExSecp256k1.html#t:error/0","title":"ExSecp256k1.error/0","type":"type"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Support freebsd target","ref":"changelog.html#0-7-2","title":"0.7.2 - Changelog","type":"extras"},{"doc":"* Use a generic ENV name to force build (https://github.com/ayrat555/ex_secp256k1/pull/20)\n* Update rustler to 0.29 (https://github.com/ayrat555/ex_secp256k1/pull/21)","ref":"changelog.html#0-7-1","title":"0.7.1 - Changelog","type":"extras"},{"doc":"* Use rust_precompiled (https://github.com/ayrat555/ex_secp256k1/pull/17)\n\nRust is not required anymore","ref":"changelog.html#0-7-0","title":"0.7.0 - Changelog","type":"extras"},{"doc":"* Update rustler to 0.26","ref":"changelog.html#0-6","title":"0.6 - Changelog","type":"extras"},{"doc":"* Update rustler to 0.24","ref":"changelog.html#0-5","title":"0.5 - Changelog","type":"extras"},{"doc":"* Add wrappers for more functions\n* Change some error atoms","ref":"changelog.html#0-4","title":"0.4 - Changelog","type":"extras"},{"doc":"* Add wrapper for public key compression","ref":"changelog.html#0-3-3","title":"0.3.3 - Changelog","type":"extras"},{"doc":"* Add wrapper for public key decompression","ref":"changelog.html#0-3-2","title":"0.3.2 - Changelog","type":"extras"},{"doc":"* Add wrapper for additive tweaking of public key","ref":"changelog.html#0-3-1","title":"0.3.1 - Changelog","type":"extras"},{"doc":"* Update rustler from 0.22 to 0.23\n* Update the libsecp256k1 rust library to 0.7.0","ref":"changelog.html#0-3-0","title":"0.3.0 - Changelog","type":"extras"},{"doc":"* Update the libsecp256k1 rust library to 0.6.0","ref":"changelog.html#0-2-1","title":"0.2.1 - Changelog","type":"extras"},{"doc":"* Update rustler to `0.22.0` for otp 24 support","ref":"changelog.html#0-2-0","title":"0.2.0 - Changelog","type":"extras"},{"doc":"* Add `sign_compact/2` and `recover_compact/3`","ref":"changelog.html#0-1-2","title":"0.1.2 - Changelog","type":"extras"},{"doc":"* Fix native files","ref":"changelog.html#0-1-1","title":"0.1.1 - Changelog","type":"extras"},{"doc":"* Initial release","ref":"changelog.html#0-1-0","title":"0.1.0 - Changelog","type":"extras"},{"doc":"# ExSecp256k1\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_secp256k1.svg)](https://hex.pm/packages/ex_secp256k1)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_secp256k1.svg)](https://hex.pm/packages/ex_secp256k1)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_secp256k1.svg)](https://hex.pm/packages/ex_secp256k1)\n[![Github.com](https://img.shields.io/github/last-commit/omgnetwork/ex_secp256k1.svg)](https://github.com/omgnetwork/ex_secp256k1)\n\nNIF for secp256k1 curve functions.\n\nIt wraps functions from the [libsecp256k1](https://github.com/paritytech/libsecp256k1) Rust library.","ref":"readme.html","title":"ExSecp256k1","type":"extras"},{"doc":"The package can be installed by adding `ex_secp256k1` to your list of\ndependencies in `mix.exs`:\n\n```elixir\n  [\n    {:ex_secp256k1, \"~> 0.7.2\"}\n  ]\n```","ref":"readme.html#installation","title":"Installation - ExSecp256k1","type":"extras"},{"doc":"The docs can be found at [https://hexdocs.pm/ex_secp256k1](https://hexdocs.pm/ex_secp256k1).","ref":"readme.html#usage","title":"Usage - ExSecp256k1","type":"extras"},{"doc":"1. [Fork it!](https://github.com/ayrat555/ex_secp256k1)\n2. Create your feature branch (`git checkout -b my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing","title":"Contributing - ExSecp256k1","type":"extras"}]}